<route lang="json5" type="page">
{
  layout: 'default',
  needLogin: true,
  style: {
    navigationBarTitleText: '工具列表',
  },
}
</route>
<template>
  <z-paging ref="paging" v-model="dataList" @query="queryList" show-refresher-update-time>
    <template #top>
      <wd-drop-menu>
        <wd-drop-menu-item v-model="fixtureType" :options="typeList" @change="handleFixtureType" />
        <wd-drop-menu-item v-model="status" :options="statusList" @change="handleFixtureStatu" />
      </wd-drop-menu>
    </template>

    <view class="bg-base">
      <wd-card type="rectangle" v-for="(item, index) in dataList" :key="item.id">
        <template #title>
          <view class="flex justify-between items-center">
            <view class="flex items-center menu-title-box">
              <view class="menu-indicator"></view>
              <text class="ml-1 text-sm">{{ item.fixtureName }}</text>
              <text class="ml-1 text-mini text-color-gray">{{ item.assetNo }}</text>
            </view>

            <view>
              <text class="icon-color-base">详情</text>
              <wd-icon name="arrow-right" custom-class="icon-color-base"></wd-icon>
            </view>
          </view>
        </template>
        <view class="flex h-[80rpx] items-center" @click.stop="itemClick(item)">
          <image class="slot-img text-center" src="/static/images/camera.png" />
          <view class="flex-1">
            <view class="text-color-base">
              <text class="text-color-gray text-mini">类型: {{ item.fixtureTypeName }}</text>
              <text class="text-color-gray ml-2 text-mini">规格: {{ item.specNo }}</text>
              <text class="text-color-gray ml-2 text-mini">型号: {{ item.modelNo }}</text>
            </view>
            <view class="text-color-gray text-sm mt-1 flex">
              <template
                v-if="!item.borrowStatus || item.borrowStatus === '0'"
              >
                <view class="flex items-center">
                  <wd-icon class="icon-color-success" name="check-outline" size="28rpx"></wd-icon>
                  <text class="ml-[2px]">空闲</text>
                </view>
              </template>

              <template
                v-if="item.borrowStatus === '1'"
              >
                <view class="flex items-center">
                  <wd-icon class="text-color-primary" name="check-outline" size="28rpx"></wd-icon>
                  <text class="ml-[2px]">借出</text>
                </view>
              </template>
              <text v-if="item.borrowUserName" class="mx-2">|</text>
              <view class="flex items-center">
                <wd-icon name="setting" size="26rpx"></wd-icon>
                <text class="ml-[2px]">{{ item.borrowUserName }}</text>
              </view>
            </view>
          </view>
          <view v-if="isSelectFixture">
            <wd-button size="small" icon="edit-outline" @click.stop="handleSelectFixture(item)">
              选中
            </wd-button>
          </view>
        </view>
      </wd-card>
    </view>
  </z-paging>
</template>

<script setup lang="ts">
import { onMounted, getCurrentInstance, ref } from 'vue'

import { getFixtureList } from '@/service/fixture'

// 工具类型
const fixtureType = ref<number>(0)
// 工具状态
const status = ref<number>(0)

const isSelectFixture = ref(false)

const typeList = ref<Record<string, any>[]>([{ label: '所有工具', value: 0 }])
const statusList = ref<Record<string, any>[]>([{ label: '所有状态', value: 0 }])
function handleFixtureType({ value }) {
  console.log(value)
}
function handleFixtureStatu({ value }) {
  console.log(value)
}

const paging = ref(null)
const dataList = ref([])

const queryList = (pageNum?: number, pageSize?: number) => {
  // 这里的pageNo和pageSize会自动计算好，直接传给服务器即可
  // 这里的请求只是演示，请替换成自己的项目的网络请求，并在网络请求回调中通过paging.value.complete(请求回来的数组)将请求结果传给z-paging
  getFixtureList({ pageNum, pageSize })
    .then((res: any) => {
      // 请勿在网络请求回调中给dataList赋值！！只需要调用complete就可以了
      paging.value.completeByTotal(res.rows, res.total)
    })
    .catch((res) => {
      // 如果请求失败写paging.value.complete(false)，会自动展示错误页面
      // 注意，每次都需要在catch中写这句话很麻烦，z-paging提供了方案可以全局统一处理
      // 在底层的网络请求抛出异常时，写uni.$emit('z-paging-error-emit');即可
      paging.value.complete(false)
    })
}

/**
 * 工具条目点击事件
 * @param item
 */
function itemClick(item: any) {}

/**
 * 其它页面选择工具
 * @param item
 */
function handleSelectFixture(item: any) {
  if (isSelectFixture.value) {
    emitSelectFixture(item)
    uni.navigateBack()
  }
}

/**
 * 选择工具回调
 * @param equ
 */
function emitSelectFixture(fixture: any) {
  eventChannel.value.emit('selectFixture', {
    data: fixture,
  })
}

const eventChannel = ref<any>()
onMounted(() => {
  const instance: any = getCurrentInstance().proxy
  const event = instance.getOpenerEventChannel()
  eventChannel.value = event
  event.on('OnSelectFixture', function (data) {
    isSelectFixture.value = true
    console.log('OnSelectFixture', data)
  })
})
</script>

<style scoped lang="scss">
.menu-title-box {
  height: 30rpx;
  line-height: 30rpx;
}

.slot-img {
  width: 72rpx;
  height: 72rpx;
  margin-right: 24rpx;
}
.text-mini {
  font-size: 22rpx;
}

.menu-indicator {
  width: 6rpx;
  height: 22rpx;
  border-radius: 10rpx;
  background-color: $uni-color-primary;
}
:deep(.wd-card__footer) {
  padding: 10rpx !important;
}
:deep(.wd-card__title-content) {
  padding: 20rpx 0 !important;
}
</style>
